/*
 * yamiXDR.c
 *
 * here are some helpers for message (de)composition
 *
 * Copyright (C) 2001-2005 Maciej Sobczak
 * http://www.msobczak.com/prog/yami/
 *
 * Permission to copy, use, modify, sell and distribute this software
 * is granted provided this copyright notice appears in all copies.
 * This software is provided "as is" without express or implied
 * warranty, and with no claim as to its suitability for any purpose.
 *
 */

#include "yamiXDR.h"
#include <stdlib.h>

/* this function returns 0 for little-endian machines, */
/* 1 otherwise (for big-endian machines)               */
char yamiXDRGetNativeByteOrder(void)
{
     int i = 1;
     return *((char*)(&i) + 3);
}

int yamiXDRRoundTo4(int ival)
{
     return ((ival + 3) & ~3);
}

char * yamiXDRWriteInt(char *pbuf, int ival)
{
     if (pbuf == NULL)
          return NULL;

     *(int*)pbuf = ival;
     return pbuf + sizeof(int);
}

const char * yamiXDRReadInt(const char *pbuf, int *pival, int swap)
{
     char *pc;

     if (pbuf == NULL)
          return NULL;

     if (swap != 0)
     {
          pc = (char*)pival;
          pc[0] = pbuf[3];
          pc[1] = pbuf[2];
          pc[2] = pbuf[1];
          pc[3] = pbuf[0];
     }
     else
          *pival = *(int*)pbuf;

     return pbuf + sizeof(int);
}

char * yamiXDRWriteDouble(char *pbuf, double dval)
{
     if (pbuf == NULL)
          return NULL;
          
     *(double*)pbuf = dval;
     return pbuf + sizeof(double);
}

const char * yamiXDRReadDouble(const char *pbuf, double *pdval, int swap)
{
     char *pc;

     if (pbuf == NULL)
          return NULL;     

     if (swap != 0)
     {
          pc = (char*)pdval;
          pc[0] = pbuf[7];
          pc[1] = pbuf[6];
          pc[2] = pbuf[5];
          pc[3] = pbuf[4];
          pc[4] = pbuf[3];
          pc[5] = pbuf[2];
          pc[6] = pbuf[1];
          pc[7] = pbuf[0];
     }
     else
          *pdval = *(double*)pbuf;

     return pbuf + sizeof(double);
}
