/*
 * yamierrors.c
 *
 * one debugging helper
 *
 * Copyright (C) 2001-2005 Maciej Sobczak
 * http://www.msobczak.com/prog/yami/
 *
 * Permission to copy, use, modify, sell and distribute this software
 * is granted provided this copyright notice appears in all copies.
 * This software is provided "as is" without express or implied
 * warranty, and with no claim as to its suitability for any purpose.
 *
 */

#include "yamierrors.h"
#include <stdlib.h>

/* returns a pointer to human-readable error description */
/* returns NULL if the code is unknown                   */
/* can be useful as a debugging help                     */
const char * yamiErrorString(int cc)
{
     static const char *ok = "Success.";
     static const char *logic[] = 
     {
          NULL,
          "Bad handle.",
          "Argument out of valid range.",
          "Object cannot be initialized twice.",
          "Wrong type.",
          "Object not initialized.",
          "Object already registered.",
          "Object not found.",
          "Queue empty.",
          "Parse error.",
          "Message cannot be processed twice.",
          "Bad length.",
          "No such service."
     };
     static const char *runtime[] = 
     {
          NULL,
          "Object not available.",
          "No memory.",
          "Address cannot be resolved.",
          "Bad address type.",
          "Cannot start thread.",
          "Thread error.",
          "Synchronization error.",
          "Network error.",
          "Overflow condition.",
          "Internal error.",
          "No hand-shake."
     };
     static size_t logicsize   = sizeof(logic)   / sizeof(const char*);
     static size_t runtimesize = sizeof(runtime) / sizeof(const char *);
     size_t index;
     
     if (cc == YAMIOK)
          return ok;
     
     if (YAMIISLOGICERROR(cc))
     {
          index = (size_t)(cc & 0xffff);
          if (index >= logicsize || index == 0)
               return NULL;
          return logic[index];
     }

     if (YAMIISRUNTIMEERROR(cc))
     {
          index = (size_t)(cc & 0xffff);
          if (index >= runtimesize || index == 0)
               return NULL;
          return runtime[index];
     }
     
     return NULL;
}
