/*
 * yamiparams.h
 *
 * this is an interface of the YAMI parameter set
 *
 * Copyright (C) 2001-2005 Maciej Sobczak
 * http://www.msobczak.com/prog/yami/
 *
 * Permission to copy, use, modify, sell and distribute this software
 * is granted provided this copyright notice appears in all copies.
 * This software is provided "as is" without express or implied
 * warranty, and with no claim as to its suitability for any purpose.
 *
 */
 
#ifndef YAMIPARAMS_INCLUDED
#define YAMIPARAMS_INCLUDED

#include <stddef.h>     /* for wchar_t in some systems */

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

#ifndef HPARAMSET_DEFINED
typedef void* HPARAMSET;
#define HPARAMSET_DEFINED
#endif

/* the types used in the Parameter Set */

enum paramType { eNoType = 0, eString = 1, eWString = 2, eInt = 3,
          eDouble = 4, eByte = 5, eBinary = 6 };

/* this is the interface supposed to be used by client code */

int yamiCreateParamSet   (HPARAMSET *pparamset, int parcount);
int yamiDestroyParamSet  (HPARAMSET paramset);
int yamiCopyParamSet     (HPARAMSET *ppsdst, HPARAMSET pssrc);
int yamiCopyParameter    (HPARAMSET psdst, int positiondst,
                          HPARAMSET pssrc, int positionsrc);

int yamiSetInt           (HPARAMSET paramset, int position, int ivalue);
int yamiSetByte          (HPARAMSET paramset, int position, char cvalue);
int yamiSetDouble        (HPARAMSET paramset, int position, double dvalue);
int yamiSetBinary        (HPARAMSET paramset, int position, const char *pbuf,
                          int bufsize);
int yamiSetBinaryShallow (HPARAMSET paramset, int position, const char *pbuf,
                          int bufsize);
int yamiSetString        (HPARAMSET paramset, int position, const char *pstr);
int yamiSetStringShallow (HPARAMSET paramset, int position, const char *pstr);
int yamiSetWString       (HPARAMSET paramset, int position,
                          const wchar_t *pwstr);
int yamiSetWStringShallow(HPARAMSET paramset, int position,
                          const wchar_t *pwstr);
int yamiGetType          (HPARAMSET paramset, int position,
                          enum paramType *ptype);
int yamiGetInt           (HPARAMSET paramset, int position, int *pivalue);
int yamiGetByte          (HPARAMSET paramset, int position, char *pcvalue);
int yamiGetDouble        (HPARAMSET paramset, int position, double *pdvalue);
int yamiGetBinarySize    (HPARAMSET paramset, int position, int *psize);
int yamiGetBinaryValue   (HPARAMSET paramset, int position, char *pbuf);
int yamiGetBinaryBuffer  (HPARAMSET paramset, int position,
                          const char **ppbuf);
int yamiIsASCIIString    (HPARAMSET paramset, int position, int *isascii);
int yamiGetStringLength  (HPARAMSET paramset, int position, int *plength);
int yamiGetStringValue   (HPARAMSET paramset, int position, char *pbuf);
int yamiGetStringBuffer  (HPARAMSET paramset, int position,
                          const char **ppbuf);
int yamiGetWStringLength (HPARAMSET paramset, int position, int *plength);
int yamiGetWStringValue  (HPARAMSET paramset, int position, wchar_t *pbuf);
int yamiGetWStringBuffer (HPARAMSET paramset, int position,
                          const wchar_t **ppbuf);
int yamiGetParamCount    (HPARAMSET paramset, int *pparcount);

/* these functions are supposed to be used by Agent */

int yamiGetPackedSize    (HPARAMSET paramset, int *packedsize);
int yamiGetPacked        (HPARAMSET paramset, char *pbuf);
int yamiCreatePSFromPacked (HPARAMSET *pps, int levelno, const char *pbuf,
                            int swap);
int yamiCheckRawBuffer   (int levelno, const char *pbuf, int swap);

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif
