/*
 * yamisynchro.h
 *
 * this is a declaration of some basic synchronization primitives
 * they are platform-independent
 *
 * Copyright (C) 2001-2005 Maciej Sobczak
 * http://www.msobczak.com/prog/yami/
 *
 * Permission to copy, use, modify, sell and distribute this software
 * is granted provided this copyright notice appears in all copies.
 * This software is provided "as is" without express or implied
 * warranty, and with no claim as to its suitability for any purpose.
 *
 */

#ifndef YAMISYNCHRO_INCLUDED
#define YAMISYNCHRO_INCLUDED


#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

typedef void* HMUTEX;
typedef void* HSEMAPHORE;


/* create and destroy mutex object */
int yamiCreateMutex(HMUTEX *pm);
int yamiDestroyMutex(HMUTEX m);

/* lock and unlock a mutex */
int yamiMutexLock(HMUTEX m);
int yamiMutexUnlock(HMUTEX m);


/* create new semaphore with the given initial value */
int yamiCreateSemaphore(HSEMAPHORE *ps, int initval);

/* destroy semaphore object */
int yamiDestroySemaphore(HSEMAPHORE s);

/* p on semaphore - can block */
int yamiSemaphoreAcquire(HSEMAPHORE s);

/* this returns 0 or YAMINOTAVAILABLE */
int yamiSemaphoreTryAcquire(HSEMAPHORE s);

/* v on semaphore */
int yamiSemaphoreRelease(HSEMAPHORE s);


/* general sleep function (for portability)   */
/* timeout is in millisecs, 0 means 'forever' */
int yamiSleep(int timeout);

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif
